@@ -98,7 +98,7 @@ def _runTaskFile(file):
     finally:
         resetPrintColor()
     if not isException:
-        _runTaskList(*taskList)
+        _runTaskList(taskList)
 
 
 # [[moduleName, parDict], ...]
@@ -121,17 +121,18 @@ def _runTaskList(taskList):
         traceback.print_exc()
         error("执行失败")
     finally:
-        resetPrintColor()
-        info("---------------------------------------------------------------------------")
 
         if countLogCritical:
-            setPrintColor(FOREGROUND_WHITE | BACKGROUND_DARKPINK)
+            color = FOREGROUND_WHITE | BACKGROUND_DARKPINK
         elif countLogError:
-            setPrintColor(FOREGROUND_WHITE | BACKGROUND_DARKRED)
+            color = FOREGROUND_WHITE | BACKGROUND_DARKRED
         elif countLogWarning:
-            setPrintColor(FOREGROUND_BLACK | BACKGROUND_DARKYELLOW)
+            color = FOREGROUND_BLACK | BACKGROUND_DARKYELLOW
         else:
-            setPrintColor(FOREGROUND_BLACK | BACKGROUND_DARKGREEN)
+            color = FOREGROUND_BLACK | BACKGROUND_DARKGREEN
+
+        setPrintColor(color)
+        info("---------------------------------------------------------------------------")
 
         msgAry = ["任务结束"]
         if countLogCritical:
@@ -141,11 +142,16 @@ def _runTaskList(taskList):
         if countLogWarning:
             msgAry.append(f"warning({countLogWarning})")
 
+        setPrintColor(color)
         info(" ".join(msgAry))
+
         passTime = str(datetime.datetime.now() - startTime)
         if passTime.startswith("0:"):
             passTime = "0" + passTime
+            
+        setPrintColor(color)
         info(f"用时：{passTime}")
+        
         resetPrintColor()
         remove(lockFile)
         if not _isDev():
